@@ -87,7 +87,7 @@ def _is_server_evacuable(server, evac_flavors, evac_images):
 
 def _get_evacuable_flavors(connection):
 	result = []
-	flavors = connection.flavors.list()
+	flavors = connection.flavors.list(is_public=None)
 	# Since the detailed view for all flavors doesn't provide the extra specs,
 	# we need to call each of the flavor to get them.
 	for flavor in flavors:
@@ -217,11 +217,11 @@ def create_nova_connection(options):
 
 	loader = loading.get_plugin_loader('password')
 	keystone_auth = loader.load_from_options(**kwargs)
-	keystone_session = session.Session(auth=keystone_auth, verify=(not options["--insecure"]))
+	keystone_session = session.Session(auth=keystone_auth, verify=not "--insecure" in options)
 
 	versions = [ "2.11", "2" ]
 	for version in versions:
-		clientargs = inspect.getargspec(client.Client).varargs
+		clientargs = inspect.getfullargspec(client.Client).varargs
 
 		# Some versions of Openstack prior to Ocata only
 		# supported positional arguments for username,
@@ -244,7 +244,7 @@ def create_nova_connection(options):
 					     None, # Password
 					     None, # Tenant
 					     None, # Auth URL
-					     insecure=options["--insecure"],
+					     insecure="--insecure" in options,
 					     region_name=options["--region-name"],
 					     endpoint_type=options["--endpoint-type"],
 					     session=keystone_session, auth=keystone_auth,
@@ -302,7 +302,7 @@ def define_new_opts():
 	all_opt["project-domain"] = {
 		"getopt" : "P:",
 		"longopt" : "project-domain",
-		"help" : "-d, --project-domain=[name]    Keystone v3 Project Domain",
+		"help" : "-P, --project-domain=[name]    Keystone v3 Project Domain",
 		"required" : "0",
 		"shortdesc" : "Keystone v3 Project Domain",
 		"default" : "Default",
@@ -332,7 +332,6 @@ def define_new_opts():
 		"help" : "--insecure                                     Explicitly allow agent to perform \"insecure\" TLS (https) requests",
 		"required" : "0",
 		"shortdesc" : "Allow Insecure TLS Requests",
-		"default" : "False",
 		"order": 2,
 	}
 	all_opt["domain"] = {
@@ -397,6 +396,11 @@ def main():
 		del options["--domain"]
 
 
+	# Disable insecure-certificate-warning message
+	if "--insecure" in options:
+		import urllib3
+		urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)
+
 	connection = create_nova_connection(options)
 
 	# Un-evacuating a server doesn't make sense
